==> haskell-feed-1.3.0.1-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-feed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 feed
version:              1.3.0.1
visibility:           public
id:                   feed-1.3.0.1-6940RZeFlwmLKYZugZLolb
key:                  feed-1.3.0.1-6940RZeFlwmLKYZugZLolb
license:              BSD-3-Clause
maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Sigbjorn Finne <sof@forkIO.com>
homepage:             https://github.com/bergmark/feed
synopsis:             Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
description:
    Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.

    To help working with the multiple feed formats we'\''ve
    ended up with, this set of modules provides parsers,
    pretty printers and some utility code for querying
    and just generally working with a concrete representation
    of feeds in Haskell.

    See here for an example of how to create an Atom feed:
    <https://github.com/bergmark/feed/blob/master/tests/Example/CreateAtom.hs>

    For basic reading and editing of feeds, consult
    the documentation of the Text.Feed.* hierarchy.

category:             Text
abi:                  9b272878c2789d2d18a6626c06d346af
exposed:              True
exposed-modules:
    Text.Atom.Feed Text.Atom.Feed.Export Text.Atom.Feed.Import
    Text.Atom.Feed.Link Text.Atom.Feed.Validate Text.Atom.Pub
    Text.Atom.Pub.Export Text.DublinCore.Types Text.Feed.Constructor
    Text.Feed.Export Text.Feed.Import Text.Feed.Query
    Text.Feed.Translate Text.Feed.Types Text.Feed.Util Text.RSS.Export
    Text.RSS.Import Text.RSS.Syntax Text.RSS1.Export Text.RSS1.Import
    Text.RSS1.Syntax Text.RSS1.Utils

hidden-modules:       Data.Text.Util Data.XML.Compat
import-dirs:          /usr/lib/ghc-8.10.2/site-local/feed-1.3.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/feed-1.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-feed
hs-libraries:         HSfeed-1.3.0.1-6940RZeFlwmLKYZugZLolb
depends:
    base-4.14.1.0 base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3
    bytestring-0.10.10.0 old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P
    old-time-1.1.0.3-4WAXseRXxLRKCRu471UUPK
    safe-0.3.19-AfrHSVViU1189qUhjBUb5b text-1.2.3.2 time-1.9.3
    time-locale-compat-0.1.1.5-75n5v6JklqyMdEmBwWBxO
    utf8-string-1.0.1.1-G1tzxDqsWge3erFqc4Oe2R
    xml-conduit-1.9.0.0-GgSI7Nc56vj7PXbl3HeHkb
    xml-types-0.3.8-1FskkqwabAiJVamcx9xCWD

haddock-interfaces:   /usr/share/doc/haskell-feed/html/feed.haddock
haddock-html:         /usr/share/doc/haskell-feed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-feed-1.3.0.1-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-feed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 feed
version:              1.3.0.1
visibility:           public
id:                   feed-1.3.0.1-9OOrB8c13K5Drq6ljyLH6u
key:                  feed-1.3.0.1-9OOrB8c13K5Drq6ljyLH6u
license:              BSD-3-Clause
maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Sigbjorn Finne <sof@forkIO.com>
homepage:             https://github.com/bergmark/feed
synopsis:             Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.
description:
    Interfacing with RSS (v 0.9x, 2.x, 1.0) + Atom feeds.

    To help working with the multiple feed formats we'\''ve
    ended up with, this set of modules provides parsers,
    pretty printers and some utility code for querying
    and just generally working with a concrete representation
    of feeds in Haskell.

    See here for an example of how to create an Atom feed:
    <https://github.com/bergmark/feed/blob/master/tests/Example/CreateAtom.hs>

    For basic reading and editing of feeds, consult
    the documentation of the Text.Feed.* hierarchy.

category:             Text
abi:                  e7e0327a78ddccef838279ca94957598
exposed:              True
exposed-modules:
    Text.Atom.Feed Text.Atom.Feed.Export Text.Atom.Feed.Import
    Text.Atom.Feed.Link Text.Atom.Feed.Validate Text.Atom.Pub
    Text.Atom.Pub.Export Text.DublinCore.Types Text.Feed.Constructor
    Text.Feed.Export Text.Feed.Import Text.Feed.Query
    Text.Feed.Translate Text.Feed.Types Text.Feed.Util Text.RSS.Export
    Text.RSS.Import Text.RSS.Syntax Text.RSS1.Export Text.RSS1.Import
    Text.RSS1.Syntax Text.RSS1.Utils

hidden-modules:       Data.Text.Util Data.XML.Compat
import-dirs:          /usr/lib/ghc-8.10.3/site-local/feed-1.3.0.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/feed-1.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-feed
hs-libraries:         HSfeed-1.3.0.1-9OOrB8c13K5Drq6ljyLH6u
depends:
    base-4.14.1.0 base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3
    bytestring-0.10.12.0 old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P
    old-time-1.1.0.3-4WAXseRXxLRKCRu471UUPK
    safe-0.3.19-AfrHSVViU1189qUhjBUb5b text-1.2.4.1 time-1.9.3
    time-locale-compat-0.1.1.5-75n5v6JklqyMdEmBwWBxO
    utf8-string-1.0.1.1-JbA4xmu2XMa1nQo1Lcnh9T
    xml-conduit-1.9.0.0-COJ9fkBs9T0C5ogrtdmJwR
    xml-types-0.3.8-9NvGZWCLGJCFNI7RY3QJQ9

haddock-interfaces:   /usr/share/doc/haskell-feed/html/feed.haddock
haddock-html:         /usr/share/doc/haskell-feed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
